==> svps-2.0.0.tgz: package/lib/tasks/steps/reboot.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { catchExec, connect, end, exec } from '../../ssh.js';
export default (VPS) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield catchExec("shutdown -r +0 \"`date '+%H:%M:%S' -d '+2 seconds'`\" & disown");
    }
    catch (quiet) { }
    try {
        yield end();
    }
    catch (quiet) { }
    return new Promise((resolve, reject) => {
        let count = 0;
        console.log('\n\x1b[0m\x1b[33m\x1b[1m⦿ Restarting\x1b[0m');
        const reconnect = setInterval(() => __awaiter(void 0, void 0, void 0, function* () {
            if (count >= 30) {
                clearInterval(reconnect);
                reject('Restarting Failed!');
            }
            try {
                yield connect(VPS);
                clearInterval(reconnect);
                yield exec('history -c');
                resolve(true);
            }
            catch (quiet) {
                count++;
            }
        }), 15000);
    });
});

==> svps-2.3.0.tgz: package/lib/tasks/steps/reboot.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { catchExec, connect, end, exec } from '../../ssh.js';
export default (VPS) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield catchExec("sudo shutdown -r +0 \"`date '+%H:%M:%S' -d '+2 seconds'`\" & disown");
    }
    catch (quiet) { }
    try {
        yield end();
    }
    catch (quiet) { }
    return new Promise((resolve, reject) => {
        let count = 0;
        console.log('\n\x1b[0m\x1b[33m\x1b[1m⦿ Restarting\x1b[0m');
        const reconnect = setInterval(() => __awaiter(void 0, void 0, void 0, function* () {
            if (count >= 30) {
                clearInterval(reconnect);
                reject('Restarting Failed!');
            }
            try {
                yield connect(VPS);
                clearInterval(reconnect);
                yield exec('history -c');
                resolve(true);
            }
            catch (quiet) {
                count++;
            }
        }), 15000);
    });
});
